@@ -70,6 +70,9 @@ public:
     /* Browser-View-Settings */
     QColor backgroundColorLoading;
     QColor backgroundColorLoaded;
+    int loadedSwitchDelay;
+
+    int defaultSideBarWidth;
 };
 
 #define qzSettings Settings::staticSettings()
